@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: filesystem.py 615 2005-02-27 01:41:45Z pronovic $
+# Revision : $Id: filesystem.py 732 2005-03-23 19:32:19Z pronovic $
 # Purpose  : Provides filesystem-related objects.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -732,10 +732,46 @@ class BackupFileList(FilesystemList):
    def _generateDigest(path):
       """
       Generates an SHA digest for a given file on disk.
+
+      The original code for this function used this simplistic implementation,
+      which requires reading the entire file into memory at once in order to
+      generate a digest value::
+
+         sha.new(open(path).read()).hexdigest()
+
+      Not surprisingly, this isn't an optimal solution.  The U{Simple file
+      hashing <http://aspn.activestate.com/ASPN/Cookbook/Python/Recipe/259109>}
+      Python Cookbook recipe describes how to incrementally generate a hash
+      value by reading in chunks of data rather than reading the file all at
+      once.  The recipe relies on the the C{update()} method of the various
+      Python hashing algorithms.
+
+      In my tests using a 110 MB file on CD, the original implementation
+      requires 111 seconds while this implementation requires only 40-45
+      seconds, which is a pretty substantial speed-up.  
+
+      Practice shows that reading in around 4kB (4096 bytes) at a time yields
+      the best performance.  Smaller reads are quite a bit slower, and larger
+      reads don't make much of a difference.  The 4kB number makes me a little
+      suspicious, and I think it might be related to the size of a filesystem
+      read at the hardware level.  However, I've decided to just hardcode 4096
+      until I have evidence that shows it's worthwhile making the read size
+      configurable.
+
       @param path: Path to generate digest for.
+
       @return: ASCII-safe SHA digest for the file.
+      @raise OSError: If the file cannot be opened.
       """
-      return sha.new(open(path).read()).hexdigest()
+      s = sha.new()
+      f = open(path)
+      readBytes = 4096  # see notes above
+      while(readBytes > 0):
+         readString = f.read(readBytes)
+         s.update(readString)
+         readBytes = len(readString)
+      f.close()
+      return s.hexdigest()
    _generateDigest = staticmethod(_generateDigest)
 
    def generateFitted(self, capacity, algorithm="worst_fit"):
@@ -1123,22 +1159,27 @@ def compareContents(path1, path2, verbose=False):
 
    @raise ValueError: If a directory doesn't exist or can't be read.
    @raise ValueError: If the two directories are not equivalent.
+   @raise IOError: If there is an unusual problem reading the directories.
    """
-   path1List = BackupFileList()
-   path1List.addDirContents(path1)
-   path1Digest = path1List.generateDigestMap(stripPrefix=normalizeDir(path1))
-   path2List = BackupFileList()
-   path2List.addDirContents(path2)
-   path2Digest = path2List.generateDigestMap(stripPrefix=normalizeDir(path2))
-   if not verbose:
-      if path1Digest != path2Digest:
-         raise ValueError("Consistency check failed.")
-   else:
-      list1 = UnorderedList(path1Digest.keys())
-      list2 = UnorderedList(path2Digest.keys())
-      if list1 != list2:
-         raise ValueError("Directories contain a different set of files.")
-      for key in list1:
-         if path1Digest[key] != path2Digest[key]:
-            raise ValueError("File contents for [%s] vary between directories." % key)
+   try:
+      path1List = BackupFileList()
+      path1List.addDirContents(path1)
+      path1Digest = path1List.generateDigestMap(stripPrefix=normalizeDir(path1))
+      path2List = BackupFileList()
+      path2List.addDirContents(path2)
+      path2Digest = path2List.generateDigestMap(stripPrefix=normalizeDir(path2))
+      if not verbose:
+         if path1Digest != path2Digest:
+            raise ValueError("Consistency check failed.")
+      else:
+         list1 = UnorderedList(path1Digest.keys())
+         list2 = UnorderedList(path2Digest.keys())
+         if list1 != list2:
+            raise ValueError("Directories contain a different set of files.")
+         for key in list1:
+            if path1Digest[key] != path2Digest[key]:
+               raise ValueError("File contents for [%s] vary between directories." % key)
+   except IOError, e:
+      logger.error("I/O error encountered during consistency check.")
+      raise e
 
